# Algo Trader Package

This is a package for the use of [algoinvest.online](https://www.algoinvst.online)

It can connect to a the Signal Provider API and execute orders on Bitmex and other providers.

# Install on pythonanywhere or on your PC

```
pip install algo-trader
```

or

```
pip install --upgrade algo-trader
```

to upgrade to newest version.